Exception: Sneaql::Exceptions::SQLTestStepExitCondition
- Inherits:
-
BaseError
- Object
- StandardError
- BaseError
- Sneaql::Exceptions::SQLTestStepExitCondition
- Defined in:
- lib/sneaql_lib/exceptions.rb
Overview
Exception used to gracefully exit test step
Instance Method Summary collapse
-
#initialize(msg = "Exit condition for this step has been met, this is not an error") ⇒ SQLTestStepExitCondition
constructor
A new instance of SQLTestStepExitCondition.
Constructor Details
#initialize(msg = "Exit condition for this step has been met, this is not an error") ⇒ SQLTestStepExitCondition
Returns a new instance of SQLTestStepExitCondition.
16 17 18 |
# File 'lib/sneaql_lib/exceptions.rb', line 16 def initialize(msg = "Exit condition for this step has been met, this is not an error") super end |